@@ -1,4 +1,4 @@
-/* GrandPerspective, Version 3.5.0 
+/* GrandPerspective, Version 3.5.1 
  *   A utility for Mac OS X that graphically shows disk usage. 
  * Copyright (C) 2005-2022, Erwin Bonsma 
  * 
@@ -217,11 +217,11 @@
 
 - (NSString *)checkNameIsValid:(NSString *)name {
   if ([name isEqualToString:@""]) {
-    return NSLocalizedString(@"The filter must have a name.", @"Alert message");
+    return NSLocalizedString(@"The filter must have a name", @"Alert message");
   }
   else if ( ![allowedName isEqualToString: name] &&
             allFilters[name] != nil) {
-    NSString  *fmt = NSLocalizedString(@"A filter named \"%@\" already exists.",
+    NSString  *fmt = NSLocalizedString(@"A filter named \"%@\" already exists",
                                        @"Alert message");
     return [NSString stringWithFormat: fmt, name];
   }
