@@ -1,4 +1,4 @@
-/* GrandPerspective, Version 3.5.0 
+/* GrandPerspective, Version 3.5.1 
  *   A utility for Mac OS X that graphically shows disk usage. 
  * Copyright (C) 2005-2022, Erwin Bonsma 
  * 
@@ -223,10 +223,10 @@
 
 - (NSString *)checkNameIsValid:(NSString *)name {
   if ([name isEqualToString:@""]) {
-    return NSLocalizedString(@"The test must have a name.", @"Alert message");
+    return NSLocalizedString(@"The test must have a name", @"Alert message");
   }
   else if (![allowedName isEqualToString: name] && allTests[name] != nil) {
-    NSString  *fmt = NSLocalizedString(@"A test named \"%@\" already exists.", @"Alert message");
+    NSString  *fmt = NSLocalizedString(@"A test named \"%@\" already exists", @"Alert message");
     return [NSString stringWithFormat: fmt, name];
   }
   
