@@ -1,4 +1,4 @@
-/* GrandPerspective, Version 3.5.0 
+/* GrandPerspective, Version 3.5.1 
  *   A utility for Mac OS X that graphically shows disk usage. 
  * Copyright (C) 2005-2022, Erwin Bonsma 
  * 
@@ -253,9 +253,9 @@ NSString  *MatchColumn = @"match";
   NSString  *fmt = NSLocalizedString(@"Remove the test named \"%@\"?", @"Alert message");
   NSString  *infoMsg = 
     ([testRepository applicationProvidedTestForName: testName] != nil)
-    ? NSLocalizedString(@"The test will be replaced by the default test with this name.",
+    ? NSLocalizedString(@"The test will be replaced by the default test with this name",
                         @"Alert informative text")
-    : NSLocalizedString(@"The test will be irrevocably removed from the test repository.",
+    : NSLocalizedString(@"The test will be irrevocably removed from the test repository",
                         @"Alert informative text");
 
   NSString  *localizedName =
