@@ -1,4 +1,4 @@
-/* GrandPerspective, Version 3.5.0 
+/* GrandPerspective, Version 3.5.1 
  *   A utility for Mac OS X that graphically shows disk usage. 
  * Copyright (C) 2005-2022, Erwin Bonsma 
  * 
@@ -31,7 +31,7 @@
   struct z_stream_s  outStream;
 }
 
-- (instancetype) init NS_DESIGNATED_INITIALIZER;
+- (instancetype) initWithPath:(NSURL *)path NS_DESIGNATED_INITIALIZER;
 
 - (BOOL) flush;
 
