@@ -1,4 +1,4 @@
-/* GrandPerspective, Version 3.5.0 
+/* GrandPerspective, Version 3.5.1 
  *   A utility for Mac OS X that graphically shows disk usage. 
  * Copyright (C) 2005-2022, Erwin Bonsma 
  * 
@@ -26,10 +26,12 @@ extern const NSUInteger TEXT_OUTPUT_BUFFER_SIZE;
   NSUInteger  dataBufferPos;
 }
 
-// Overrides designated initialiser
-- (instancetype) init NS_DESIGNATED_INITIALIZER;
+- (instancetype) init NS_UNAVAILABLE;
+- (instancetype) initWithPath:(NSURL *)path NS_DESIGNATED_INITIALIZER;
 
-- (BOOL) open:(NSString *)filename;
+@property (nonatomic, strong, readonly) NSURL *path;
+
+- (BOOL) open;
 - (BOOL) close;
 
 - (BOOL) appendString:(NSString *)s;
