@@ -1,4 +1,4 @@
-/* GrandPerspective, Version 3.5.0 
+/* GrandPerspective, Version 3.5.1 
  *   A utility for Mac OS X that graphically shows disk usage. 
  * Copyright (C) 2005-2022, Erwin Bonsma 
  * 
@@ -29,13 +29,13 @@
 - (instancetype) init NS_UNAVAILABLE;
 
 - (instancetype) initWithAnnotatedTreeContext:(AnnotatedTreeContext *)context
-                                         path:(NSString *)path;
+                                         path:(NSURL *)path;
 - (instancetype) initWithAnnotatedTreeContext:(AnnotatedTreeContext *)context
-                                         path:(NSString *)path
+                                         path:(NSURL *)path
                                       options:(id)options NS_DESIGNATED_INITIALIZER;
 
 @property (nonatomic, readonly, strong) AnnotatedTreeContext *annotatedTreeContext;
-@property (nonatomic, readonly, copy) NSString *path;
+@property (nonatomic, readonly, strong) NSURL *path;
 @property (nonatomic, readonly, strong) id options;
 
 @end
