@@ -1,4 +1,4 @@
-/* GrandPerspective, Version 3.5.0 
+/* GrandPerspective, Version 3.5.1 
  *   A utility for Mac OS X that graphically shows disk usage. 
  * Copyright (C) 2005-2022, Erwin Bonsma 
  * 
@@ -23,12 +23,12 @@
 @implementation WriteTaskInput
 
 - (instancetype) initWithAnnotatedTreeContext:(AnnotatedTreeContext *)context
-                                         path:(NSString *)path {
+                                         path:(NSURL *)path {
   return [self initWithAnnotatedTreeContext: context path: path options: nil];
 }
 
 - (instancetype) initWithAnnotatedTreeContext:(AnnotatedTreeContext *)context
-                                         path:(NSString *)path
+                                         path:(NSURL *)path
                                       options:(id)options {
   if (self = [super init]) {
     _annotatedTreeContext = [context retain];
