@@ -1,4 +1,4 @@
-/* GrandPerspective, Version 3.5.0 
+/* GrandPerspective, Version 3.5.1 
  *   A utility for Mac OS X that graphically shows disk usage. 
  * Copyright (C) 2005-2022, Erwin Bonsma 
  * 
@@ -85,7 +85,7 @@
     alert.messageText = NSLocalizedString
       (@"Inaccuracies in hard-linked folder contents", @"Alert message");
     alert.informativeText = NSLocalizedString
-      (@"The refreshed content may not be fully accurate. Hard-linked items may occur more than once or could be missing. Perform a rescan to ensure that each hard-linked item occurs only once.",
+      (@"The refreshed content may not be fully accurate. Hard-linked items may occur more than once or could be missing. Perform a rescan to ensure that each hard-linked item occurs only once",
        @"Alert message");
     return alert;
   }
